==> dpws-model-1.1.0-sources.jar: org/somda/sdc/dpws/soap/wsmetadataexchange/model/MetadataSection.java <==

package org.somda.sdc.dpws.soap.wsmetadataexchange.model;

import java.util.HashMap;
import java.util.Map;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAnyAttribute;
import javax.xml.bind.annotation.XmlAnyElement;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import javax.xml.namespace.QName;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString2;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy2;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;
import org.somda.sdc.dpws.soap.wsaddressing.model.EndpointReferenceType;
import org.w3c.dom.Element;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;choice&gt;
 *         &lt;any processContents='lax' namespace='##other'/&gt;
 *         &lt;element ref="{http://schemas.xmlsoap.org/ws/2004/09/mex}MetadataReference"/&gt;
 *         &lt;element ref="{http://schemas.xmlsoap.org/ws/2004/09/mex}Location"/&gt;
 *       &lt;/choice&gt;
 *       &lt;attribute name="Dialect" use="required" type="{http://www.w3.org/2001/XMLSchema}anyURI" /&gt;
 *       &lt;attribute name="Identifier" type="{http://www.w3.org/2001/XMLSchema}anyURI" /&gt;
 *       &lt;anyAttribute processContents='lax' namespace='##other'/&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "any",
    "metadataReference",
    "location"
})
@XmlRootElement(name = "MetadataSection", namespace = "http://schemas.xmlsoap.org/ws/2004/09/mex")
public class MetadataSection implements ToString2
{

    @XmlAnyElement(lax = true)
    protected Object any;
    @XmlElement(name = "MetadataReference", namespace = "http://schemas.xmlsoap.org/ws/2004/09/mex")
    protected EndpointReferenceType metadataReference;
    @XmlElement(name = "Location", namespace = "http://schemas.xmlsoap.org/ws/2004/09/mex")
    @XmlSchemaType(name = "anyURI")
    protected String location;
    @XmlAttribute(name = "Dialect", required = true)
    @XmlSchemaType(name = "anyURI")
    protected String dialect;
    @XmlAttribute(name = "Identifier")
    @XmlSchemaType(name = "anyURI")
    protected String identifier;
    @XmlAnyAttribute
    private Map<QName, String> otherAttributes = new HashMap<QName, String>();

    /**
     * Ruft den Wert der any-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link Element }
     *     {@link Object }
     *     
     */
    public Object getAny() {
        return any;
    }

    /**
     * Legt den Wert der any-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link Element }
     *     {@link Object }
     *     
     */
    public void setAny(Object value) {
        this.any = value;
    }

    /**
     * Ruft den Wert der metadataReference-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link EndpointReferenceType }
     *     
     */
    public EndpointReferenceType getMetadataReference() {
        return metadataReference;
    }

    /**
     * Legt den Wert der metadataReference-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link EndpointReferenceType }
     *     
     */
    public void setMetadataReference(EndpointReferenceType value) {
        this.metadataReference = value;
    }

    /**
     * Ruft den Wert der location-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLocation() {
        return location;
    }

    /**
     * Legt den Wert der location-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLocation(String value) {
        this.location = value;
    }

    /**
     * Ruft den Wert der dialect-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDialect() {
        return dialect;
    }

    /**
     * Legt den Wert der dialect-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDialect(String value) {
        this.dialect = value;
    }

    /**
     * Ruft den Wert der identifier-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getIdentifier() {
        return identifier;
    }

    /**
     * Legt den Wert der identifier-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setIdentifier(String value) {
        this.identifier = value;
    }

    /**
     * Gets a map that contains attributes that aren't bound to any typed property on this class.
     * 
     * <p>
     * the map is keyed by the name of the attribute and 
     * the value is the string value of the attribute.
     * 
     * the map returned by this method is live, and you can add new attribute
     * by updating the map directly. Because of this design, there's no setter.
     * 
     * 
     * @return
     *     always non-null
     */
    public Map<QName, String> getOtherAttributes() {
        return otherAttributes;
    }

    public boolean equals(Object object) {
        if ((object == null)||(this.getClass()!= object.getClass())) {
            return false;
        }
        if (this == object) {
            return true;
        }
        final MetadataSection that = ((MetadataSection) object);
        {
            Object leftAny;
            leftAny = this.getAny();
            Object rightAny;
            rightAny = that.getAny();
            if (this.any!= null) {
                if (that.any!= null) {
                    if (!leftAny.equals(rightAny)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.any!= null) {
                    return false;
                }
            }
        }
        {
            EndpointReferenceType leftMetadataReference;
            leftMetadataReference = this.getMetadataReference();
            EndpointReferenceType rightMetadataReference;
            rightMetadataReference = that.getMetadataReference();
            if (this.metadataReference!= null) {
                if (that.metadataReference!= null) {
                    if (!leftMetadataReference.equals(rightMetadataReference)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.metadataReference!= null) {
                    return false;
                }
            }
        }
        {
            String leftLocation;
            leftLocation = this.getLocation();
            String rightLocation;
            rightLocation = that.getLocation();
            if (this.location!= null) {
                if (that.location!= null) {
                    if (!leftLocation.equals(rightLocation)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.location!= null) {
                    return false;
                }
            }
        }
        {
            String leftDialect;
            leftDialect = this.getDialect();
            String rightDialect;
            rightDialect = that.getDialect();
            if (this.dialect!= null) {
                if (that.dialect!= null) {
                    if (!leftDialect.equals(rightDialect)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.dialect!= null) {
                    return false;
                }
            }
        }
        {
            String leftIdentifier;
            leftIdentifier = this.getIdentifier();
            String rightIdentifier;
            rightIdentifier = that.getIdentifier();
            if (this.identifier!= null) {
                if (that.identifier!= null) {
                    if (!leftIdentifier.equals(rightIdentifier)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.identifier!= null) {
                    return false;
                }
            }
        }
        return true;
    }

    public int hashCode() {
        int currentHashCode = 1;
        {
            currentHashCode = (currentHashCode* 31);
            Object theAny;
            theAny = this.getAny();
            if (this.any!= null) {
                currentHashCode += theAny.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            EndpointReferenceType theMetadataReference;
            theMetadataReference = this.getMetadataReference();
            if (this.metadataReference!= null) {
                currentHashCode += theMetadataReference.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            String theLocation;
            theLocation = this.getLocation();
            if (this.location!= null) {
                currentHashCode += theLocation.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            String theDialect;
            theDialect = this.getDialect();
            if (this.dialect!= null) {
                currentHashCode += theDialect.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            String theIdentifier;
            theIdentifier = this.getIdentifier();
            if (this.identifier!= null) {
                currentHashCode += theIdentifier.hashCode();
            }
        }
        return currentHashCode;
    }

    public String toString() {
        final ToStringStrategy2 strategy = JAXBToStringStrategy.INSTANCE2;
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        {
            Object theAny;
            theAny = this.getAny();
            strategy.appendField(locator, this, "any", buffer, theAny, (this.any!= null));
        }
        {
            EndpointReferenceType theMetadataReference;
            theMetadataReference = this.getMetadataReference();
            strategy.appendField(locator, this, "metadataReference", buffer, theMetadataReference, (this.metadataReference!= null));
        }
        {
            String theLocation;
            theLocation = this.getLocation();
            strategy.appendField(locator, this, "location", buffer, theLocation, (this.location!= null));
        }
        {
            String theDialect;
            theDialect = this.getDialect();
            strategy.appendField(locator, this, "dialect", buffer, theDialect, (this.dialect!= null));
        }
        {
            String theIdentifier;
            theIdentifier = this.getIdentifier();
            strategy.appendField(locator, this, "identifier", buffer, theIdentifier, (this.identifier!= null));
        }
        return buffer;
    }

}

==> dpws-model-2.0.0-sources.jar: org/somda/sdc/dpws/soap/wsmetadataexchange/model/MetadataSection.java <==

package org.somda.sdc.dpws.soap.wsmetadataexchange.model;

import java.util.HashMap;
import java.util.Map;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAnyAttribute;
import javax.xml.bind.annotation.XmlAnyElement;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import javax.xml.namespace.QName;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString2;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy2;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;
import org.somda.sdc.dpws.soap.wsaddressing.model.EndpointReferenceType;
import org.w3c.dom.Element;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;choice&gt;
 *         &lt;any processContents='lax' namespace='##other'/&gt;
 *         &lt;element ref="{http://schemas.xmlsoap.org/ws/2004/09/mex}MetadataReference"/&gt;
 *         &lt;element ref="{http://schemas.xmlsoap.org/ws/2004/09/mex}Location"/&gt;
 *       &lt;/choice&gt;
 *       &lt;attribute name="Dialect" use="required" type="{http://www.w3.org/2001/XMLSchema}anyURI" /&gt;
 *       &lt;attribute name="Identifier" type="{http://www.w3.org/2001/XMLSchema}anyURI" /&gt;
 *       &lt;anyAttribute processContents='lax' namespace='##other'/&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "any",
    "metadataReference",
    "location"
})
@XmlRootElement(name = "MetadataSection", namespace = "http://schemas.xmlsoap.org/ws/2004/09/mex")
public class MetadataSection implements ToString2
{

    @XmlAnyElement(lax = true)
    protected Object any;
    @XmlElement(name = "MetadataReference", namespace = "http://schemas.xmlsoap.org/ws/2004/09/mex")
    protected EndpointReferenceType metadataReference;
    @XmlElement(name = "Location", namespace = "http://schemas.xmlsoap.org/ws/2004/09/mex")
    @XmlSchemaType(name = "anyURI")
    protected String location;
    @XmlAttribute(name = "Dialect", required = true)
    @XmlSchemaType(name = "anyURI")
    protected String dialect;
    @XmlAttribute(name = "Identifier")
    @XmlSchemaType(name = "anyURI")
    protected String identifier;
    @XmlAnyAttribute
    private Map<QName, String> otherAttributes = new HashMap<QName, String>();

    /**
     * Gets the value of the any property.
     * 
     * @return
     *     possible object is
     *     {@link Element }
     *     {@link Object }
     *     
     */
    public Object getAny() {
        return any;
    }

    /**
     * Sets the value of the any property.
     * 
     * @param value
     *     allowed object is
     *     {@link Element }
     *     {@link Object }
     *     
     */
    public void setAny(Object value) {
        this.any = value;
    }

    /**
     * Gets the value of the metadataReference property.
     * 
     * @return
     *     possible object is
     *     {@link EndpointReferenceType }
     *     
     */
    public EndpointReferenceType getMetadataReference() {
        return metadataReference;
    }

    /**
     * Sets the value of the metadataReference property.
     * 
     * @param value
     *     allowed object is
     *     {@link EndpointReferenceType }
     *     
     */
    public void setMetadataReference(EndpointReferenceType value) {
        this.metadataReference = value;
    }

    /**
     * Gets the value of the location property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLocation() {
        return location;
    }

    /**
     * Sets the value of the location property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLocation(String value) {
        this.location = value;
    }

    /**
     * Gets the value of the dialect property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDialect() {
        return dialect;
    }

    /**
     * Sets the value of the dialect property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDialect(String value) {
        this.dialect = value;
    }

    /**
     * Gets the value of the identifier property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getIdentifier() {
        return identifier;
    }

    /**
     * Sets the value of the identifier property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setIdentifier(String value) {
        this.identifier = value;
    }

    /**
     * Gets a map that contains attributes that aren't bound to any typed property on this class.
     * 
     * <p>
     * the map is keyed by the name of the attribute and 
     * the value is the string value of the attribute.
     * 
     * the map returned by this method is live, and you can add new attribute
     * by updating the map directly. Because of this design, there's no setter.
     * 
     * 
     * @return
     *     always non-null
     */
    public Map<QName, String> getOtherAttributes() {
        return otherAttributes;
    }

    public boolean equals(Object object) {
        if ((object == null)||(this.getClass()!= object.getClass())) {
            return false;
        }
        if (this == object) {
            return true;
        }
        final MetadataSection that = ((MetadataSection) object);
        {
            Object leftAny;
            leftAny = this.getAny();
            Object rightAny;
            rightAny = that.getAny();
            if (this.any!= null) {
                if (that.any!= null) {
                    if (!leftAny.equals(rightAny)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.any!= null) {
                    return false;
                }
            }
        }
        {
            EndpointReferenceType leftMetadataReference;
            leftMetadataReference = this.getMetadataReference();
            EndpointReferenceType rightMetadataReference;
            rightMetadataReference = that.getMetadataReference();
            if (this.metadataReference!= null) {
                if (that.metadataReference!= null) {
                    if (!leftMetadataReference.equals(rightMetadataReference)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.metadataReference!= null) {
                    return false;
                }
            }
        }
        {
            String leftLocation;
            leftLocation = this.getLocation();
            String rightLocation;
            rightLocation = that.getLocation();
            if (this.location!= null) {
                if (that.location!= null) {
                    if (!leftLocation.equals(rightLocation)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.location!= null) {
                    return false;
                }
            }
        }
        {
            String leftDialect;
            leftDialect = this.getDialect();
            String rightDialect;
            rightDialect = that.getDialect();
            if (this.dialect!= null) {
                if (that.dialect!= null) {
                    if (!leftDialect.equals(rightDialect)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.dialect!= null) {
                    return false;
                }
            }
        }
        {
            String leftIdentifier;
            leftIdentifier = this.getIdentifier();
            String rightIdentifier;
            rightIdentifier = that.getIdentifier();
            if (this.identifier!= null) {
                if (that.identifier!= null) {
                    if (!leftIdentifier.equals(rightIdentifier)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.identifier!= null) {
                    return false;
                }
            }
        }
        return true;
    }

    public int hashCode() {
        int currentHashCode = 1;
        {
            currentHashCode = (currentHashCode* 31);
            Object theAny;
            theAny = this.getAny();
            if (this.any!= null) {
                currentHashCode += theAny.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            EndpointReferenceType theMetadataReference;
            theMetadataReference = this.getMetadataReference();
            if (this.metadataReference!= null) {
                currentHashCode += theMetadataReference.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            String theLocation;
            theLocation = this.getLocation();
            if (this.location!= null) {
                currentHashCode += theLocation.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            String theDialect;
            theDialect = this.getDialect();
            if (this.dialect!= null) {
                currentHashCode += theDialect.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            String theIdentifier;
            theIdentifier = this.getIdentifier();
            if (this.identifier!= null) {
                currentHashCode += theIdentifier.hashCode();
            }
        }
        return currentHashCode;
    }

    public String toString() {
        final ToStringStrategy2 strategy = JAXBToStringStrategy.INSTANCE2;
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        {
            Object theAny;
            theAny = this.getAny();
            strategy.appendField(locator, this, "any", buffer, theAny, (this.any!= null));
        }
        {
            EndpointReferenceType theMetadataReference;
            theMetadataReference = this.getMetadataReference();
            strategy.appendField(locator, this, "metadataReference", buffer, theMetadataReference, (this.metadataReference!= null));
        }
        {
            String theLocation;
            theLocation = this.getLocation();
            strategy.appendField(locator, this, "location", buffer, theLocation, (this.location!= null));
        }
        {
            String theDialect;
            theDialect = this.getDialect();
            strategy.appendField(locator, this, "dialect", buffer, theDialect, (this.dialect!= null));
        }
        {
            String theIdentifier;
            theIdentifier = this.getIdentifier();
            strategy.appendField(locator, this, "identifier", buffer, theIdentifier, (this.identifier!= null));
        }
        return buffer;
    }

}
